gchecky.model.merchant_calculated_shipping_t

Package gchecky :: Module model :: Class merchant_calculated_shipping_t |
[hide private]
[frames] | no frames]

# Class merchant_calculated_shipping_t

source code

       object --+
                |
        gxml.Node --+
                    |
    shipping_option_t --+
                        |
                       merchant_calculated_shipping_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| address_filters = `Node:PATH(address-filters):OPT:{ address_fil`...``
| _fields = ``{``'``address_filters``'``:` Node:PATH(address-filters):OPT:{`...``
Inherited from `shipping_option_t`: `allowed_areas`, `excluded_areas`, `name`, `price`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### address_filters Value:
      Node:PATH(address-filters):OPT:{ address_filters_t }

  ### _fields Value:
      {'address_filters': Node:PATH(address-filters):OPT:{ address_filters_t
       },
       'allowed_areas': Node:PATH(shipping-restrictions/allowed-areas):OPT:{
       allowed_areas_t },
       'excluded_areas': Node:PATH(shipping-restrictions/excluded-areas):OPT
      :{ excluded_areas_t },
       'name': String:PATH(@name):REQ:EMPTY,
       'price': Node:PATH(price):REQ:{ price_t }}